pytilities.geometry

Package pytilities :: Package geometry |
[hide private]
[frames] | no frames]

# Package geometry

source code

All sorts of geometry trinkets

Classes:

> Vector
>   2D Point/Vector
> BoundVector
>   Vector whose x and y values are stored elsewhere.
> ImmutableVector
>   Vector wrapper that makes the vector immutable.
> VerboseVector
>   Vector wrapper that sends out events.
> Rectangle
>   A rectangle identified by two points.
> VerboseRectangle
>   Rectangle wrapper that sends out events

Submodules | [hide private]
pytilities.geometry.boundvector pytilities.geometry.immutablevector pytilities.geometry.rectangle pytilities.geometry.vector pytilities.geometry.verboserectangle pytilities.geometry.verbosevector

Variables | [hide private]
| __package__ = ``'``pytilities.geometry``'``